==> open-xchange-documentconverter-api_7.8.2.orig.tar.bz2: open-xchange-documentconverter-api-7.8.2/com.openexchange.documentconverter/src/com/openexchange/documentconverter/DataSourceFileInputStream.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentconverter;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;

/**
 * {@link DataSourceFileInputStream}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.8.2
 */
public class DataSourceFileInputStream extends ObjectInputStream {

    final private static String oldPackagePrefix = "com.openexchange.documentconverter.impl.";
    final private static String newPackagePrefix = "com.openexchange.documentconverter.";

    /**
     * Initializes a new {@link DataSourceFileInputStream}.
     * @throws IOException
     * @throws SecurityException
     */
    protected DataSourceFileInputStream() throws IOException, SecurityException {
        super();
    }

    /**
     * Initializes a new {@link DataSourceFileInputStream}.
     * @param inputStm
     * @throws IOException
     */
    public DataSourceFileInputStream(InputStream inputStm) throws IOException {
        super(inputStm);
    }

    /* (non-Javadoc)
     * @see java.io.ObjectInputStream#readClassDescriptor()
     */
    @Override
    protected ObjectStreamClass readClassDescriptor() throws IOException, ClassNotFoundException {
        ObjectStreamClass objStmClass = super.readClassDescriptor();

        if (objStmClass.getName().startsWith(oldPackagePrefix)) {
            return ObjectStreamClass.lookup(Class.forName(objStmClass.getName().replace(oldPackagePrefix, newPackagePrefix)));
        }

        return objStmClass;
    }
}

==> open-xchange-documentconverter-api_7.10.1.orig.tar.bz2: open-xchange-documentconverter-api-7.10.1/com.openexchange.documentconverter/src/com/openexchange/documentconverter/DataSourceFileInputStream.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.documentconverter;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;

/**
 * {@link DataSourceFileInputStream}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 * @since v7.8.2
 */
public class DataSourceFileInputStream extends ObjectInputStream {

    final private static String oldPackagePrefix = "com.openexchange.documentconverter.impl.";
    final private static String newPackagePrefix = "com.openexchange.documentconverter.";

    /**
     * Initializes a new {@link DataSourceFileInputStream}.
     * @throws IOException
     * @throws SecurityException
     */
    protected DataSourceFileInputStream() throws IOException, SecurityException {
        super();
    }

    /**
     * Initializes a new {@link DataSourceFileInputStream}.
     * @param inputStm
     * @throws IOException
     */
    public DataSourceFileInputStream(InputStream inputStm) throws IOException {
        super(inputStm);
    }

    /* (non-Javadoc)
     * @see java.io.ObjectInputStream#readClassDescriptor()
     */
    @Override
    public ObjectStreamClass readClassDescriptor() throws IOException, ClassNotFoundException {
        ObjectStreamClass objStmClass = super.readClassDescriptor();

        if (objStmClass.getName().startsWith(oldPackagePrefix)) {
            return ObjectStreamClass.lookup(Class.forName(objStmClass.getName().replace(oldPackagePrefix, newPackagePrefix)));
        }

        return objStmClass;
    }
}
